@@ -24,13 +24,15 @@ from .controller.table_controller import AuthController
 from .engine.database_engine import DatabaseEngine
 from .engine.disk_engine import DiskEngine
 from .engine.redis_engine import RedisEngine
+from .enums.str_int import EnumStr
 from .exception.register_handlers import register_exception_handlers
 from .exception.service_exception import (
     AuthException,
     LoginException,
     PermissionException,
     ServiceErrorException,
-    DataNotFoundException
+    DataNotFoundException,
+    ValueException
 )
 from .generate.config import GeneratorConfig
 from .logger.logging_ import logging
@@ -38,6 +40,7 @@ from .schemas.query_request import QueryRequest
 from .schemas.response import BaseResponse
 from .services.auth_service import AuthService
 from .services.data_service import DataService
+from .services.query_service import QueryService
 from .services.db_engine_service import DBEngineService
 from .services.enum_service import EnumService
 from .services.generate_service import GeneratorService
